==> MIDITrail-Ver.1.2.1a-Windows_src.zip: MIDITrail/MIDITrail/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MIDITrail.rc
//
#define IDC_MYICON                      2
#define IDD_MENUWINDOW_DIALOG           102
#define IDS_APP_TITLE                   103
#define IDD_ABOUTBOX                    103
#define IDM_ABOUT                       104
#define IDM_EXIT                        105
#define IDI_MIDITRAIL                   107
#define IDI_SMALL                       108
#define IDC_MENUWINDOW                  109
#define IDC_MIDITRAIL                   110
#define IDR_MAINFRAME                   128
#define IDD_MIDIOUT_CFG                 129
#define IDD_WINDOWSIZE_CFG              130
#define IDD_HOWTOVIEW                   131
#define IDD_GRAPHIC_CFG                 132
#define IDD_MIDIIN_CFG                  133
#define IDC_COMBO_PORT_A                1000
#define IDC_COMBO_PORT_B                1001
#define IDC_COMBO_PORT_C                1002
#define IDC_COMBO_PORT_D                1003
#define IDC_COMBO_PORT_E                1004
#define IDC_COMBO_PORT_F                1005
#define IDC_WINDOWSIZE_LIST             1006
#define IDC_HOWTO_PICTURE               1009
#define IDC_COMBO_MULTISAMPLETYPE       1010
#define IDC_BTN_PREVIOUS                1011
#define IDC_BTN_NEXT                    1012
#define IDC_BTN_CLOSE                   1013
#define IDC_CHECK_MIDITHRU              1016
#define IDC_TEXT_VERSION                1017
#define IDC_TEXT_COPYRIGHT              1018
#define IDM_OPEN_FILE                   32771
#define IDM_PLAY                        32772
#define IDM_STOP                        32773
#define IDM_VIEW_3DPIANOROLL            32774
#define IDM_OPTION_MIDIOUT              32775
#define IDM_WINDOWSIZE                  32776
#define IDM_REPEAT                      32787
#define IDM_RESET_VIEWPOINT             32790
#define IDM_SAVE_VIEWPOINT              32791
#define IDM_HOWTOVIEW                   32792
#define IDM_MANUAL                      32794
#define IDM_VIEW_2DPIANOROLL            32796
#define IDM_ENABLE_PIANOKEYBOARD        32803
#define IDM_ENABLE_RIPPLE               32804
#define IDM_ENABLE_PITCHBEND            32805
#define IDM_VIEW_PIANOROLLRAIN          32807
#define IDM_OPTION_GRAPHIC              32809
#define IDM_ENABLE_STARS                32817
#define IDM_ENABLE_COUNTER              32818
#define IDM_SKIP_BACK                   32823
#define IDM_SKIP_FORWARD                32824
#define IDM_PLAY_SPEED_DOWN             32825
#define IDM_PLAY_SPEED_UP               32826
#define IDM_OPTION_MIDIIN               32832
#define IDM_START_MONITORING            32835
#define IDM_STOP_MONITORING             32836
#define IDM_AUTO_SAVE_VIEWPOINT         32838
#define IDM_VIEW_PIANOROLLRAIN2D        32840
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        134
#define _APS_NEXT_COMMAND_VALUE         32841
#define _APS_NEXT_CONTROL_VALUE         1019
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif

==> MIDITrail-Ver.1.2.4-Windows_src.zip: MIDITrail/MIDITrail/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MIDITrail.rc
//
#define IDC_MYICON                      2
#define IDD_MENUWINDOW_DIALOG           102
#define IDS_APP_TITLE                   103
#define IDD_ABOUTBOX                    103
#define IDM_ABOUT                       104
#define IDM_EXIT                        105
#define IDI_MIDITRAIL                   107
#define IDI_SMALL                       108
#define IDC_MENUWINDOW                  109
#define IDC_MIDITRAIL                   110
#define IDR_MAINFRAME                   128
#define IDD_MIDIOUT_CFG                 129
#define IDD_WINDOWSIZE_CFG              130
#define IDD_HOWTOVIEW                   131
#define IDD_GRAPHIC_CFG                 132
#define IDD_MIDIIN_CFG                  133
#define IDC_COMBO_PORT_A                1000
#define IDC_COMBO_PORT_B                1001
#define IDC_COMBO_PORT_C                1002
#define IDC_COMBO_PORT_D                1003
#define IDC_COMBO_PORT_E                1004
#define IDC_COMBO_PORT_F                1005
#define IDC_WINDOWSIZE_LIST             1006
#define IDC_HOWTO_PICTURE               1009
#define IDC_COMBO_MULTISAMPLETYPE       1010
#define IDC_BTN_PREVIOUS                1011
#define IDC_BTN_NEXT                    1012
#define IDC_BTN_CLOSE                   1013
#define IDC_CHECK_MIDITHRU              1016
#define IDC_TEXT_VERSION                1017
#define IDC_TEXT_COPYRIGHT              1018
#define IDC_CHECK_APPLY_TO_VIEW         1019
#define IDC_EDIT_WIDTH                  1020
#define IDC_EDIT_HEIGHT                 1021
#define IDC_EDIT_IMAGE_FILE_PATH        1022
#define IDC_BTN_BROWSE                  1023
#define IDM_OPEN_FILE                   32771
#define IDM_PLAY                        32772
#define IDM_STOP                        32773
#define IDM_VIEW_3DPIANOROLL            32774
#define IDM_OPTION_MIDIOUT              32775
#define IDM_WINDOWSIZE                  32776
#define IDM_REPEAT                      32787
#define IDM_RESET_VIEWPOINT             32790
#define IDM_SAVE_VIEWPOINT              32791
#define IDM_HOWTOVIEW                   32792
#define IDM_MANUAL                      32794
#define IDM_VIEW_2DPIANOROLL            32796
#define IDM_ENABLE_PIANOKEYBOARD        32803
#define IDM_ENABLE_RIPPLE               32804
#define IDM_ENABLE_PITCHBEND            32805
#define IDM_VIEW_PIANOROLLRAIN          32807
#define IDM_OPTION_GRAPHIC              32809
#define IDM_ENABLE_STARS                32817
#define IDM_ENABLE_COUNTER              32818
#define IDM_SKIP_BACK                   32823
#define IDM_SKIP_FORWARD                32824
#define IDM_PLAY_SPEED_DOWN             32825
#define IDM_PLAY_SPEED_UP               32826
#define IDM_OPTION_MIDIIN               32832
#define IDM_START_MONITORING            32835
#define IDM_STOP_MONITORING             32836
#define IDM_AUTO_SAVE_VIEWPOINT         32838
#define IDM_VIEW_PIANOROLLRAIN2D        32840
#define IDM_ENABLE_BACKGROUNDIMAGE      32842
#define IDM_VIEWPOINT2                  32843
#define IDM_VIEWPOINT3                  32844
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        134
#define _APS_NEXT_COMMAND_VALUE         32848
#define _APS_NEXT_CONTROL_VALUE         1024
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif
